# Pydung

**An experimental 3D console game.**

![Short film of it.](https://i.imgur.com/wy8kN8S.gif)

## Running
After installing the game via pip, to run, simply perform the following
command:

    python -m pydung

## Controls
* **Move:** Arrow keys/WASD
* **Jump:** Ctrl/Spacebar
* **Sprint:** Z
* **Quit:** Q
* **Reset:** R
* **Zero Gravity:** G